pub fn render_border(
x: i32,
y: i32,
width: u16,
height: u16,
style: &Style,
grid: &mut Grid,
level: ColorLevel,
)Expand description
Draw the border of a box node into grid.
(x, y) is the top-left corner of the box (absolute grid coordinates).
width / height are the full computed dimensions including border cells.
Mirrors renderBorder in render-border.ts:22-155, including stylePiece.